@@ -1112,6 +1112,9 @@ void BufferParams::validate(LaTeXFeatures & features) const
 {
 	features.require(documentClass().requires());
 
+	if (columns > 1 && language->rightToLeft())
+		features.require("rtloutputdblcol");
+
 	if (outputChanges) {
 		bool dvipost    = LaTeXFeatures::isAvailable("dvipost");
 		bool xcolorulem = LaTeXFeatures::isAvailable("ulem") &&
@@ -1386,15 +1389,27 @@ bool BufferParams::writeLaTeX(otexstream & os, LaTeXFeatures & features,
 	// XeTeX and LuaTeX (with OS fonts) work without fontenc
 	if (font_encoding() != "default" && language->lang() != "japanese"
 	    && !useNonTeXFonts && !tclass.provides("fontenc")) {
+		docstring extra_encoding;
+		if (features.mustProvide("textgreek"))
+			extra_encoding += from_ascii("LGR");
+		if (features.mustProvide("textcyr")) {
+			if (!extra_encoding.empty())
+				extra_encoding.push_back(',');
+			extra_encoding += from_ascii("T2A");
+		}
+		if (!extra_encoding.empty() && !font_encoding().empty())
+			extra_encoding.push_back(',');
 		size_t fars = language_options.str().find("farsi");
 		size_t arab = language_options.str().find("arabic");
 		if (language->lang() == "arabic_arabi"
 			|| language->lang() == "farsi" || fars != string::npos
 			|| arab != string::npos) {
-			os << "\\usepackage[" << from_ascii(font_encoding())
+			os << "\\usepackage[" << extra_encoding
+			   << from_ascii(font_encoding())
 			   << ",LFE,LAE]{fontenc}\n";
 		} else {
-			os << "\\usepackage[" << from_ascii(font_encoding())
+			os << "\\usepackage[" << extra_encoding
+			   << from_ascii(font_encoding())
 			   << "]{fontenc}\n";
 		}
 	}
@@ -2130,17 +2145,24 @@ bool BufferParams::isExportableFormat(string const & format) const
 vector<string> BufferParams::backends() const
 {
 	vector<string> v;
-	v.push_back(bufferFormat());
+	string const buffmt = bufferFormat();
+
 	// FIXME: Don't hardcode format names here, but use a flag
-	if (v.back() == "latex") {
-		v.push_back("pdflatex");
+	if (buffmt == "latex") {
+		if (!useNonTeXFonts) {
+			v.push_back("pdflatex");
+			v.push_back("latex");
+		}
 		v.push_back("luatex");
 		v.push_back("dviluatex");
 		v.push_back("xetex");
-	} else if (v.back() == "xetex") {
+	} else if (buffmt == "xetex") {
+		v.push_back("xetex");
 		v.push_back("luatex");
 		v.push_back("dviluatex");
-	}
+	} else
+		v.push_back(buffmt);
+
 	v.push_back("xhtml");
 	v.push_back("text");
 	v.push_back("lyx");
@@ -2160,8 +2182,22 @@ OutputParams::FLAVOR BufferParams::getOutputFlavor(string const format) const
 
 	OutputParams::FLAVOR result = OutputParams::LATEX;
 
+	// FIXME It'd be better not to hardcode this, but to do
+	//       something with formats.
 	if (dformat == "xhtml")
 		result = OutputParams::HTML;
+	else if (dformat == "text")
+		result = OutputParams::TEXT;
+	else if (dformat == "pdflatex")
+ 		result = OutputParams::PDFLATEX;
+	else if (dformat == "xetex")
+		result = OutputParams::XETEX;
+	else if (dformat == "luatex")
+		result = OutputParams::LUATEX;
+	else if (dformat == "dviluatex")
+		result = OutputParams::DVILUATEX;
+	else if (dformat == "lyx")
+		result = OutputParams::LYX;
 	else {
 		// Try to determine flavor of default output format
 		vector<string> backs = backends();
@@ -2604,7 +2640,8 @@ string BufferParams::babelCall(string const & lang_opts, bool const langoptions)
 	if (lang_package != "auto" && lang_package != "babel"
 	    && lang_package != "default" && lang_package != "none")
 		return lang_package;
-	if (lyxrc.language_package_selection == LyXRC::LP_CUSTOM)
+	if (lang_package == "default"
+	    && lyxrc.language_package_selection == LyXRC::LP_CUSTOM)
 		return lyxrc.language_custom_package;
 	// suppress the babel call if there is no BabelName defined
 	// for the document language in the lib/languages file and if no
