@@ -1778,7 +1778,7 @@ void BufferView::dispatch(FuncRequest const & cmd, DispatchResult & dr)
 			cur.forwardInset();
 		cur.beginUndoGroup();
 		while(cur && iterations < max_iter) {
-			Inset * ins = cur.nextInset();
+			Inset * const ins = cur.nextInset();
 			if (!ins)
 				break;
 			docstring insname = ins->layoutName();
@@ -1794,7 +1794,9 @@ void BufferView::dispatch(FuncRequest const & cmd, DispatchResult & dr)
 					break;
 				insname = insname.substr(0, i);
 			}
-			cur.forwardInset();
+			// if we did not delete the inset, skip it
+			if (!cur.nextInset() || cur.nextInset() == ins)
+				cur.forwardInset();
 		}
 		cur.endUndoGroup();
 		cur = savecur;
@@ -2443,6 +2445,8 @@ bool BufferView::mouseSetCursor(Cursor & cur, bool select)
 		cap::saveSelection(cursor());
 
 	d->cursor_.macroModeClose();
+	// If a macro has been finalized, the cursor might have been broken
+	cur.fixIfBroken();
 
 	// Has the cursor just left the inset?
 	bool const leftinset = (&d->cursor_.inset() != &cur.inset());
