@@ -255,13 +255,13 @@ pasteSelectionHelper(Cursor const & cur, ParagraphList const & parlist,
 						if (ref->getParam("reference") == oldname)
 							ref->setParam("reference", newname);
 					} else if (itt->lyxCode() == MATH_REF_CODE) {
-						InsetMathHull * mi = itt->asInsetMath()->asHullInset();
+						InsetMathRef * mi = itt->asInsetMath()->asRefInset();
 						// this is necessary to prevent an uninitialized
 						// buffer when the RefInset is in a MathBox.
 						// FIXME audit setBuffer calls
 						mi->setBuffer(const_cast<Buffer &>(buffer));
-						if (mi->asRefInset()->getTarget() == oldname)
-							mi->asRefInset()->changeTarget(newname);
+						if (mi->getTarget() == oldname)
+							mi->changeTarget(newname);
 					}
 				}
 			}
@@ -285,14 +285,13 @@ pasteSelectionHelper(Cursor const & cur, ParagraphList const & parlist,
 					if (ref.getParam("reference") == oldname)
 						ref.setParam("reference", newname);
 				} else if (itt->lyxCode() == MATH_REF_CODE) {
-					InsetMathHull & mi =
-						static_cast<InsetMathHull &>(*itt);
+					InsetMathRef * mi = itt->asInsetMath()->asRefInset();
 					// this is necessary to prevent an uninitialized
 					// buffer when the RefInset is in a MathBox.
 					// FIXME audit setBuffer calls
-					mi.setBuffer(const_cast<Buffer &>(buffer));
-					if (mi.asRefInset()->getTarget() == oldname)
-						mi.asRefInset()->changeTarget(newname);
+					mi->setBuffer(const_cast<Buffer &>(buffer));
+					if (mi->getTarget() == oldname)
+						mi->changeTarget(newname);
 				}
 			}
 			break;
@@ -470,8 +469,8 @@ void putClipboard(ParagraphList const & paragraphs,
 	// a DocumentClass, via new, that is never deleted. If we were to go to
 	// some kind of garbage collection there, or a shared_ptr, then this
 	// would not be needed.
-	static Buffer * buffer = theBufferList().newBuffer(
-		FileName::tempName().absFileName() + "_clipboard.internal");
+	static Buffer * buffer = theBufferList().newInternalBuffer(
+		FileName::tempName("clipboard.internal").absFileName());
 	buffer->setUnnamed(true);
 	buffer->paragraphs() = paragraphs;
 	buffer->inset().setBuffer(*buffer);
@@ -528,7 +527,7 @@ void copySelectionHelper(Buffer const & buf, Text const & text,
 	ParagraphList::iterator it = copy_pars.begin();
 	ParagraphList::iterator it_end = copy_pars.end();
 
-	for (; it != it_end; it++) {
+	for (; it != it_end; ++it) {
 		// Since we have a copy of the paragraphs, the insets
 		// do not have a proper buffer reference. It makes
 		// sense to add them temporarily, because the
@@ -553,7 +552,7 @@ void copySelectionHelper(Buffer const & buf, Text const & text,
 	// do some final cleanup now, to make sure that the paragraphs
 	// are not linked to something else.
 	it = copy_pars.begin();
-	for (; it != it_end; it++) {
+	for (; it != it_end; ++it) {
 		it->setBuffer(*static_cast<Buffer *>(0));
 		it->setInsetOwner(0);
 	}
@@ -1005,7 +1004,6 @@ void pasteFromStack(Cursor & cur, ErrorList & errorList, size_t sel_index)
 	cur.recordUndo();
 	pasteParagraphList(cur, theCuts[sel_index].first,
 			   theCuts[sel_index].second, errorList);
-	cur.setSelection();
 }
 
 
@@ -1029,7 +1027,6 @@ void pasteClipboardText(Cursor & cur, ErrorList & errorList, bool asParagraphs)
 				cur.recordUndo();
 				pasteParagraphList(cur, buffer.paragraphs(),
 					buffer.params().documentClassPtr(), errorList);
-				cur.setSelection();
 				return;
 			}
 		}
@@ -1044,7 +1041,6 @@ void pasteClipboardText(Cursor & cur, ErrorList & errorList, bool asParagraphs)
 		cur.text()->insertStringAsParagraphs(cur, text, cur.current_font);
 	else
 		cur.text()->insertStringAsLines(cur, text, cur.current_font);
-	cur.setSelection();
 }
 
 
@@ -1078,7 +1074,7 @@ void pasteSelection(Cursor & cur, ErrorList & errorList)
 }
 
 
-void replaceSelectionWithString(Cursor & cur, docstring const & str, bool backwards)
+void replaceSelectionWithString(Cursor & cur, docstring const & str)
 {
 	cur.recordUndo();
 	DocIterator selbeg = cur.selectionBegin();
@@ -1097,13 +1093,6 @@ void replaceSelectionWithString(Cursor & cur, docstring const & str, bool backwa
 
 	// Cut the selection
 	cutSelection(cur, true, false);
-
-	// select the replacement
-	if (backwards) {
-		selbeg.pos() += str.length();
-		cur.setSelection(selbeg, -int(str.length()));
-	} else
-		cur.setSelection(selbeg, str.length());
 }
 
 
