@@ -182,19 +182,19 @@ static docstring const changetracking_dvipost_def = from_ascii(
 	"\\dvipost{osend color pop}\n"
 	"\\dvipost{cbstart color push Blue}\n"
 	"\\dvipost{cbend color pop}\n"
-	"\\newcommand{\\lyxadded}[3]{\\changestart#3\\changeend}\n"
-	"\\newcommand{\\lyxdeleted}[3]{%\n"
+	"\\DeclareRobustCommand{\\lyxadded}[3]{\\changestart#3\\changeend}\n"
+	"\\DeclareRobustCommand{\\lyxdeleted}[3]{%\n"
 	"\\changestart\\overstrikeon#3\\overstrikeoff\\changeend}\n");
 
 static docstring const changetracking_xcolor_ulem_def = from_ascii(
 	"%% Change tracking with ulem\n"
-	"\\newcommand{\\lyxadded}[3]{{\\color{lyxadded}{}#3}}\n"
-	"\\newcommand{\\lyxdeleted}[3]{{\\color{lyxdeleted}\\sout{#3}}}\n");
+	"\\DeclareRobustCommand{\\lyxadded}[3]{{\\color{lyxadded}{}#3}}\n"
+	"\\DeclareRobustCommand{\\lyxdeleted}[3]{{\\color{lyxdeleted}\\sout{#3}}}\n");
 
 static docstring const changetracking_xcolor_ulem_hyperref_def = from_ascii(
 	"%% Change tracking with ulem\n"
-	"\\newcommand{\\lyxadded}[3]{{\\texorpdfstring{\\color{lyxadded}{}}{}#3}}\n"
-	"\\newcommand{\\lyxdeleted}[3]{{\\texorpdfstring{\\color{lyxdeleted}\\sout{#3}}{}}}\n");
+	"\\DeclareRobustCommand{\\lyxadded}[3]{{\\texorpdfstring{\\color{lyxadded}{}}{}#3}}\n"
+	"\\DeclareRobustCommand{\\lyxdeleted}[3]{{\\texorpdfstring{\\color{lyxdeleted}\\sout{#3}}{}}}\n");
 
 static docstring const changetracking_none_def = from_ascii(
 	"\\newcommand{\\lyxadded}[3]{#3}\n"
@@ -275,6 +275,42 @@ static docstring const lyxref_def = from_ascii(
 		"  {\\def\\RSlemtxt{lemma~}\\newref{lem}{name = \\RSlemtxt}}\n" 
 		"  {}\n");
 
+// Make sure the columns are also outputed as rtl
+static docstring const rtloutputdblcol_def = from_ascii(
+	"\\def\\@outputdblcol{%\n"
+	"  \\if@firstcolumn\n"
+	"    \\global \\@firstcolumnfalse\n"
+	"    \\global \\setbox\\@leftcolumn \\box\\@outputbox\n"
+	"  \\else\n"
+	"    \\global \\@firstcolumntrue\n"
+	"    \\setbox\\@outputbox \\vbox {%\n"
+	"      \\hb@xt@\\textwidth {%\n"
+	"      \\kern\\textwidth \\kern-\\columnwidth %**\n"
+	"      \\hb@xt@\\columnwidth {%\n"
+	"         \\box\\@leftcolumn \\hss}%\n"
+	"      \\kern-\\textwidth %**\n"
+	"      \\hfil\n"
+	"      {\\normalcolor\\vrule \\@width\\columnseprule}%\n"
+	"      \\hfil\n"
+	"      \\kern-\\textwidth  %**\n"
+	"      \\hb@xt@\\columnwidth {%\n"
+	"         \\box\\@outputbox \\hss}%\n"
+	"      \\kern-\\columnwidth \\kern\\textwidth %**\n"
+	"    }%\n"
+	"  }%\n"
+	"  \\@combinedblfloats\n"
+	"  \\@outputpage\n"
+	"  \\begingroup\n"
+	"  \\@dblfloatplacement\n"
+	"  \\@startdblcolumn\n"
+	"  \\@whilesw\\if@fcolmade \\fi\n"
+	"  {\\@outputpage\n"
+	"    \\@startdblcolumn}%\n"
+	"  \\endgroup\n"
+	"  \\fi\n"
+	"}\n"
+	"\\@mparswitchtrue\n");
+
 
 /////////////////////////////////////////////////////////////////////
 //
@@ -291,17 +327,13 @@ LaTeXFeatures::LaTeXFeatures(Buffer const & b, BufferParams const & p,
 
 bool LaTeXFeatures::useBabel() const
 {
-	if (usePolyglossia())
+	if (usePolyglossia()
+	    || bufferParams().lang_package == "none"
+	    || (bufferParams().lang_package == "default"
+	        && lyxrc.language_package_selection == LyXRC::LP_NONE))
 		return false;
-	if (bufferParams().lang_package == "default")
-		return (lyxrc.language_package_selection != LyXRC::LP_NONE)
-			|| (bufferParams().language->lang() != lyxrc.default_language
-			    && !bufferParams().language->babel().empty())
-			|| this->hasLanguages();
-	return (bufferParams().lang_package != "none")
-		|| (bufferParams().language->lang() != lyxrc.default_language
-		    && !bufferParams().language->babel().empty())
-		|| this->hasLanguages();
+
+	return !bufferParams().language->babel().empty() || this->hasLanguages();
 }
 
 
@@ -554,6 +586,7 @@ char const * simplefeatures[] = {
 	"units",
 	"tipa",
 	"tipx",
+	"tone",
 	"framed",
 	"soul",
 	"textcomp",
@@ -963,6 +996,9 @@ docstring const LaTeXFeatures::getMacros() const
 	if (mustProvide("ct-none"))
 		macros << changetracking_none_def;
 
+	if (mustProvide("rtloutputdblcol"))
+		macros << rtloutputdblcol_def;
+
 	return macros.str();
 }
 
@@ -979,7 +1015,10 @@ string const LaTeXFeatures::getBabelPresettings() const
 	if (!params_.language->babel_presettings().empty())
 		tmp << params_.language->babel_presettings() << '\n';
 
-	return tmp.str();
+	if (!contains(tmp.str(), '@'))
+		return tmp.str();
+
+	return "\\makeatletter\n" + tmp.str() + "\\makeatother\n";
 }
 
 
@@ -995,7 +1034,10 @@ string const LaTeXFeatures::getBabelPostsettings() const
 	if (!params_.language->babel_postsettings().empty())
 		tmp << params_.language->babel_postsettings() << '\n';
 
-	return tmp.str();
+	if (!contains(tmp.str(), '@'))
+		return tmp.str();
+
+	return "\\makeatletter\n" + tmp.str() + "\\makeatother\n";
 }
 
 
