@@ -331,6 +331,7 @@ public:
 	///
 	void latexSpecialChar(
 				   otexstream & os,
+				   BufferParams const & bparams,
 				   OutputParams const & runparams,
 				   Font const & running_font,
 				   Change const & running_change,
@@ -1068,6 +1069,7 @@ void Paragraph::Private::latexInset(BufferParams const & bparams,
 	odocstream::pos_type const len = os.os().tellp();
 
 	if (inset->forceLTR()
+	    && !runparams.use_polyglossia
 	    && running_font.isRightToLeft()
 	    // ERT is an exception, it should be output with no
 	    // decorations at all
@@ -1147,6 +1149,7 @@ void Paragraph::Private::latexInset(BufferParams const & bparams,
 
 
 void Paragraph::Private::latexSpecialChar(otexstream & os,
+					  BufferParams const & bparams,
 					  OutputParams const & runparams,
 					  Font const & running_font,
 					  Change const & running_change,
@@ -1155,7 +1158,10 @@ void Paragraph::Private::latexSpecialChar(otexstream & os,
 					  pos_type end_pos,
 					  unsigned int & column)
 {
-	char_type const c = text_[i];
+	// With polyglossia, brackets and stuff need not be reversed
+	// in RTL scripts (see bug #8251)
+	char_type const c = (runparams.use_polyglossia) ?
+		owner_->getUChar(bparams, i) : text_[i];
 
 	if (style.pass_thru || runparams.pass_thru) {
 		if (c != '\0') {
@@ -1834,16 +1840,23 @@ FontSize Paragraph::highestFontInRange
 char_type Paragraph::getUChar(BufferParams const & bparams, pos_type pos) const
 {
 	char_type c = d->text_[pos];
-	if (!lyxrc.rtl_support)
+	if (!lyxrc.rtl_support || !getFontSettings(bparams, pos).isRightToLeft())
 		return c;
 
+	// FIXME: The arabic special casing is due to the difference of arabic
+	// round brackets input introduced in r18599. Check if this should be
+	// unified with Hebrew or at least if all bracket types should be
+	// handled the same (file format change in either case).
+	string const & lang = getFontSettings(bparams, pos).language()->lang();
+	bool const arabic = lang == "arabic_arabtex" || lang == "arabic_arabi" ||
+		lang == "farsi";
 	char_type uc = c;
 	switch (c) {
 	case '(':
-		uc = ')';
+		uc = arabic ? c : ')';
 		break;
 	case ')':
-		uc = '(';
+		uc = arabic ? c : '(';
 		break;
 	case '[':
 		uc = ']';
@@ -1864,9 +1877,8 @@ char_type Paragraph::getUChar(BufferParams const & bparams, pos_type pos) const
 		uc = '<';
 		break;
 	}
-	if (uc != c && getFontSettings(bparams, pos).isRightToLeft())
-		return uc;
-	return c;
+
+	return uc;
 }
 
 
@@ -2504,7 +2516,7 @@ void Paragraph::latex(BufferParams const & bparams,
 		} else {
 			if (i >= start_pos && (end_pos == -1 || i < end_pos)) {
 				try {
-					d->latexSpecialChar(os, rp, running_font, runningChange,
+					d->latexSpecialChar(os, bparams, rp, running_font, runningChange,
 							    style, i, end_pos, column);
 				} catch (EncodingException & e) {
 				if (runparams.dryrun) {
@@ -2775,14 +2787,15 @@ docstring Paragraph::simpleLyXHTMLOnePar(Buffer const & buf,
 		if (inset) {
 			if (!runparams.for_toc || inset->isInToc()) {
 				OutputParams np = runparams;
+				np.local_font = &font;
 				if (!inset->getLayout().htmlisblock())
 					np.html_in_par = true;
 				retval += inset->xhtml(xs, np);
 			}
 		} else {
-			char_type c = d->text_[i];
+			char_type c = getUChar(buf.params(), i);
 
-			if (style.pass_thru)
+			if (style.pass_thru || runparams.pass_thru)
 				xs << c;
 			else if (c == '-') {
 				docstring str;
@@ -3167,70 +3180,61 @@ char_type Paragraph::transformChar(char_type c, pos_type pos) const
 }
 
 
-int Paragraph::checkBiblio(Buffer const & buffer)
+bool Paragraph::brokenBiblio() const
 {
-	// FIXME From JS:
-	// This is getting more and more a mess. ...We really should clean
-	// up this bibitem issue for 1.6.
+	// there is a problem if there is no bibitem at position 0 or
+	// if there is another bibitem in the paragraph.
+	return d->layout_->labeltype == LABEL_BIBLIO
+		&& (d->insetlist_.find(BIBITEM_CODE) != 0
+		    || d->insetlist_.find(BIBITEM_CODE, 1) > 0);
+}
+
+
+int Paragraph::fixBiblio(Buffer const & buffer)
+{
+	// FIXME: What about the case where paragraph is not BIBLIO
+	// but there is an InsetBibitem?
+	// FIXME: when there was already an inset at 0, the return value is 1,
+	// which does not tell whether another inset has been remove; the
+	// cursor cannot be correctly updated.
 
-	// Add bibitem insets if necessary
 	if (d->layout_->labeltype != LABEL_BIBLIO)
 		return 0;
 
-	bool hasbibitem = !d->insetlist_.empty()
-		// Insist on it being in pos 0
-		&& d->text_[0] == META_INSET
-		&& d->insetlist_.begin()->inset->lyxCode() == BIBITEM_CODE;
+	bool const track_changes = buffer.params().trackChanges;
+	int bibitem_pos = d->insetlist_.find(BIBITEM_CODE);
+	bool const hasbibitem0 = bibitem_pos == 0;
 
-	bool track_changes = buffer.params().trackChanges;
-
-	docstring oldkey;
-	docstring oldlabel;
-
-	// remove a bibitem in pos != 0
-	// restore it later in pos 0 if necessary
-	// (e.g. if a user inserts contents _before_ the item)
-	// we're assuming there's only one of these, which there
-	// should be.
-	int erasedInsetPosition = -1;
-	InsetList::iterator it = d->insetlist_.begin();
-	InsetList::iterator end = d->insetlist_.end();
-	for (; it != end; ++it)
-		if (it->inset->lyxCode() == BIBITEM_CODE
-		      && it->pos > 0) {
-			InsetCommand * olditem = it->inset->asInsetCommand();
-			oldkey = olditem->getParam("key");
-			oldlabel = olditem->getParam("label");
-			erasedInsetPosition = it->pos;
-			eraseChar(erasedInsetPosition, track_changes);
-			break;
-	}
-
-	// There was an InsetBibitem at the beginning, and we didn't
-	// have to erase one.
-	if (hasbibitem && erasedInsetPosition < 0)
+	if (hasbibitem0) {
+		bibitem_pos = d->insetlist_.find(BIBITEM_CODE, 1);
+		// There was an InsetBibitem at pos 0, and no other one => OK
+		if (bibitem_pos == -1)
 			return 0;
-
-	// There was an InsetBibitem at the beginning and we did have to
-	// erase one. So we give its properties to the beginning inset.
-	if (hasbibitem) {
-		InsetCommand * inset = d->insetlist_.begin()->inset->asInsetCommand();
-		if (!oldkey.empty())
-			inset->setParam("key", oldkey);
-		inset->setParam("label", oldlabel);
-		return -erasedInsetPosition;
+		// there is a bibitem at the 0 position, but since
+		// there is a second one, we copy the second on the
+		// first. We're assuming there are at most two of
+		// these, which there should be.
+		// FIXME: why does it make sense to do that rather
+		// than keep the first? (JMarc)
+		Inset * inset = d->insetlist_.release(bibitem_pos);
+		eraseChar(bibitem_pos, track_changes);
+		d->insetlist_.begin()->inset = inset;
+		return -bibitem_pos;
 	}
 
-	// There was no inset at the beginning, so we need to create one with
-	// the key and label of the one we erased.
-	InsetBibitem * inset =
-		new InsetBibitem(const_cast<Buffer *>(&buffer), InsetCommandParams(BIBITEM_CODE));
-	// restore values of previously deleted item in this par.
-	if (!oldkey.empty())
-		inset->setParam("key", oldkey);
-	inset->setParam("label", oldlabel);
-	insertInset(0, inset,
-		    Change(track_changes ? Change::INSERTED : Change::UNCHANGED));
+	// We need to create an inset at the beginning
+	Inset * inset = 0;
+	if (bibitem_pos > 0) {
+		// there was one somewhere in the paragraph, let's move it
+		inset = d->insetlist_.release(bibitem_pos);
+		eraseChar(bibitem_pos, track_changes);
+	} else
+		// make a fresh one
+		inset = new InsetBibitem(const_cast<Buffer *>(&buffer),
+					 InsetCommandParams(BIBITEM_CODE));
+
+	insertInset(0, inset, Change(track_changes ? Change::INSERTED 
+				                   : Change::UNCHANGED));
 
 	return 1;
 }
