@@ -283,7 +283,11 @@ static bool doInsertInset(Cursor & cur, Text * text,
 			// Merge multiple paragraphs -- hack
 			while (cur.lastpit() > 0)
 				mergeParagraph(bparams, cur.text()->paragraphs(), 0);
+			Cursor old = cur;
 			cur.leaveInset(*inset);
+			if (cmd.action() == LFUN_PREVIEW_INSERT)
+				// trigger preview
+				notifyCursorLeavesOrEnters(old, cur);
 		}
 	} else {
 		cur.leaveInset(*inset);
@@ -905,15 +909,12 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 	case LFUN_NEWLINE_INSERT: {
 		InsetNewlineParams inp;
 		docstring arg = cmd.argument();
-		// this avoids a double undo
-		// FIXME: should not be needed, ideally
-		if (!cur.selection())
-			cur.recordUndo();
-		cap::replaceSelection(cur);
 		if (arg == "linebreak")
 			inp.kind = InsetNewlineParams::LINEBREAK;
 		else
 			inp.kind = InsetNewlineParams::NEWLINE;
+		cap::replaceSelection(cur);
+		cur.recordUndo();
 		cur.insert(new InsetNewline(inp));
 		cur.posForward();
 		moveCursor(cur, false);
@@ -1314,13 +1315,14 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 	}
 
 	case LFUN_CLIPBOARD_PASTE:
-		cur.clearSelection();
+		cap::replaceSelection(cur);
 		pasteClipboardText(cur, bv->buffer().errorList("Paste"),
 			       cmd.argument() == "paragraph");
 		bv->buffer().errors("Paste");
 		break;
 
 	case LFUN_PRIMARY_SELECTION_PASTE:
+		cap::replaceSelection(cur);
 		pasteString(cur, theSelection().get(),
 			    cmd.argument() == "paragraph");
 		break;
@@ -1329,6 +1331,7 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 		// Copy the selection buffer to the clipboard stack,
 		// because we want it to appear in the "Edit->Paste
 		// recent" menu.
+		cap::replaceSelection(cur);
 		cap::copySelectionToStack();
 		cap::pasteSelection(bv->cursor(), bv->buffer().errorList("Paste"));
 		bv->buffer().errors("Paste");
@@ -1350,14 +1353,14 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 	}
 
 	case LFUN_QUOTE_INSERT: {
-		// this avoids a double undo
-		// FIXME: should not be needed, ideally
-		if (!cur.selection())
-			cur.recordUndo();
 		cap::replaceSelection(cur);
+		cur.recordUndo();
 
 		Paragraph const & par = cur.paragraph();
 		pos_type pos = cur.pos();
+		// Ignore deleted text before cursor
+		while (pos > 0 && par.isDeleted(pos - 1))
+			--pos;
 
 		BufferParams const & bufparams = bv->buffer().params();
 		bool const hebrew = 
@@ -1893,12 +1896,19 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 	}
 
 	case LFUN_LANGUAGE: {
-		Language const * lang = languages.getLanguage(to_utf8(cmd.argument()));
-		if (!lang)
+		string const lang_arg = cmd.getArg(0);
+		bool const reset = (lang_arg.empty() || lang_arg == "reset");
+		Language const * lang =
+			reset ? reset_language
+			      : languages.getLanguage(lang_arg);
+		// we allow reset_language, which is 0, but only if it
+		// was requested via empty or "reset" arg.
+		if (!lang && !reset)
 			break;
+		bool const toggle = (cmd.getArg(1) != "set");
 		selectWordWhenUnderCursor(cur, WHOLE_WORD_STRICT);
 		Font font(ignore_font, lang);
-		toggleAndShow(cur, this, font, false);
+		toggleAndShow(cur, this, font, toggle);
 		break;
 	}
 
@@ -2244,6 +2254,7 @@ bool Text::getStatus(Cursor & cur, FuncRequest const & cmd,
 
 	FontInfo const & fontinfo = cur.real_current_font.fontInfo();
 	bool enable = true;
+	bool allow_in_passthru = false;
 	InsetCode code = NO_CODE;
 
 	switch (cmd.action()) {
@@ -2434,6 +2445,7 @@ bool Text::getStatus(Cursor & cur, FuncRequest const & cmd,
 		break;
 	case LFUN_ARGUMENT_INSERT: {
 		code = ARG_CODE;
+		allow_in_passthru = true;
 		Layout const & lay = cur.paragraph().layout();
 		int const numargs = lay.reqargs + lay.optargs;
 		enable = cur.paragraph().insetList().count(ARG_CODE) < numargs;
@@ -2665,7 +2677,7 @@ bool Text::getStatus(Cursor & cur, FuncRequest const & cmd,
 
 	case LFUN_LANGUAGE:
 		enable = !cur.paragraph().isPassThru();
-		flag.setOnOff(to_utf8(cmd.argument()) == cur.real_current_font.language()->lang());
+		flag.setOnOff(cmd.getArg(0) == cur.real_current_font.language()->lang());
 		break;
 
 	case LFUN_BREAK_PARAGRAPH:
@@ -2798,7 +2810,7 @@ bool Text::getStatus(Cursor & cur, FuncRequest const & cmd,
 	if (code != NO_CODE
 	    && (cur.empty() 
 		|| !cur.inset().insetAllowed(code)
-		|| cur.paragraph().layout().pass_thru))
+		|| (cur.paragraph().layout().pass_thru && !allow_in_passthru)))
 		enable = false;
 
 	flag.setEnabled(enable);
@@ -2809,7 +2821,6 @@ bool Text::getStatus(Cursor & cur, FuncRequest const & cmd,
 void Text::pasteString(Cursor & cur, docstring const & clip,
 		bool asParagraphs)
 {
-	cur.clearSelection();
 	if (!clip.empty()) {
 		cur.recordUndo();
 		if (asParagraphs)
