@@ -375,19 +375,28 @@ bool TextMetrics::redoParagraph(pit_type const pit)
 	main_text_ = (text_ == &buffer.text());
 	bool changed = false;
 
+	// Check whether there are InsetBibItems that need fixing
 	// FIXME: This check ought to be done somewhere else. It is the reason
-	// why text_ is not	const. But then, where else to do it?
+	// why text_ is not const. But then, where else to do it?
 	// Well, how can you end up with either (a) a biblio environment that
 	// has no InsetBibitem or (b) a biblio environment with more than one
 	// InsetBibitem? I think the answer is: when paragraphs are merged;
 	// when layout is set; when material is pasted.
-	int const moveCursor = par.checkBiblio(buffer);
-	if (moveCursor > 0)
-		const_cast<Cursor &>(bv_->cursor()).posForward();
-	else if (moveCursor < 0) {
-		Cursor & cursor = const_cast<Cursor &>(bv_->cursor());
-		if (cursor.pos() >= -moveCursor)
-			cursor.posBackward();
+	if (par.brokenBiblio()) {
+		Cursor & cur = const_cast<Cursor &>(bv_->cursor());
+		// In some cases, we do not know how to record undo
+		if (&cur.inset() == &text_->inset())
+			cur.recordUndo(ATOMIC_UNDO, pit, pit);
+
+		int const moveCursor = par.fixBiblio(buffer);
+
+		// Is it necessary to update the cursor?
+		if (&cur.inset() == &text_->inset() && cur.pit() == pit) {
+			if (moveCursor > 0)
+				cur.posForward();
+			else if (moveCursor < 0 && cur.pos() >= -moveCursor)
+				cur.posBackward();
+		}
 	}
 
 	// Optimisation: this is used in the next two loops
