@@ -1089,8 +1089,13 @@ static docstring makeDispatchMessage(docstring const & msg,
 
 void GuiApplication::dispatch(FuncRequest const & cmd)
 {
-	if (current_view_ && current_view_->currentBufferView())
+	Buffer * buffer = 0;
+	if (current_view_ && current_view_->currentBufferView()) {
 		current_view_->currentBufferView()->cursor().saveBeforeDispatchPosXY();
+		buffer = &current_view_->currentBufferView()->buffer();
+		if (buffer)
+			buffer->undo().beginUndoGroup();
+	}
 
 	DispatchResult dr;
 	// redraw the screen at the end (first of the two drawing steps).
@@ -1098,6 +1103,10 @@ void GuiApplication::dispatch(FuncRequest const & cmd)
 	dr.screenUpdate(Update::FitCursor);
 	dispatch(cmd, dr);
 	updateCurrentView(cmd, dr);
+
+	// the buffer may have been closed by one action
+	if (theBufferList().isLoaded(buffer))
+		buffer->undo().endUndoGroup();
 }
 
 
@@ -1950,10 +1959,7 @@ void GuiApplication::exit(int status)
 
 void GuiApplication::setGuiLanguage()
 {
-	// Set the language defined by the user.
-	setRcGuiLanguage();
-
-	QString const default_language = toqstr(Messages::defaultLanguage());
+	QString const default_language = toqstr(getGuiMessages().language());
 	LYXERR(Debug::LOCALE, "Trying to set default locale to: " << default_language);
 	QLocale const default_locale(default_language);
 	QLocale::setDefault(default_locale);
