@@ -783,7 +783,11 @@ void MenuDefinition::expandSpellingSuggestions(BufferView const * bv)
 					MenuItem w(MenuItem::Command, toqstr(suggestion),
 						FuncRequest(LFUN_WORD_REPLACE, 
 							replace2string(suggestion, selection,
-								true, true, false, true, false)));
+								true,     // case sensitive
+								true,     // match word
+								false,    // all words
+								true,     // forward
+								false))); // find next
 					if (i < m)
 						add(w);
 					else
@@ -883,7 +887,7 @@ void MenuDefinition::expandLanguageSelector(Buffer const * buf)
 			}
 		}
 		MenuItem w(MenuItem::Command, label,
-			FuncRequest(LFUN_LANGUAGE, (*cit)->lang()));
+			FuncRequest(LFUN_LANGUAGE, (*cit)->lang() + " set"));
 		item.submenu().addWithStatusCheck(w);
 	}
 	item.submenu().add(MenuItem(MenuItem::Separator));
@@ -950,7 +954,7 @@ void MenuDefinition::expandDocuments()
 	// We cannot use a for loop as the buffer list cycles.
 	do {
 		bool const shown = guiApp->currentView()
-			? guiApp->currentView()->workArea(*b) : false;
+			? bool(guiApp->currentView()->workArea(*b)) : false;
 		if (!shown) {
 			QString label = toqstr(b->fileName().displayName(20));
 			if (!b->isClean())
