@@ -1079,6 +1079,12 @@ string InsetGraphics::params2string(InsetGraphicsParams const & params,
 	return data.str();
 }
 
+
+docstring InsetGraphics::toolTip(BufferView const &, int, int) const
+{
+	return from_utf8(params().filename.onlyFileName());
+}
+
 namespace graphics {
 
 void getGraphicsGroups(Buffer const & b, set<string> & ids)
