@@ -527,32 +527,90 @@ void InsetInclude::latex(otexstream & os, OutputParams const & runparams) const
 			mangledFileName();
 	}
 
-	FileName const writefile(makeAbsPath(mangled, masterBuffer->temppath()));
-
 	if (!runparams.nice)
 		incfile = mangled;
 	else if (!isValidLaTeXFileName(incfile)) {
 		frontend::Alert::warning(_("Invalid filename"),
 			_("The following filename will cause troubles "
-			  "when running the exported file through LaTeX: ") +
+				"when running the exported file through LaTeX: ") +
 			from_utf8(incfile));
-	}
-	else if (!isValidDVIFileName(incfile)) {
+	} else if (!isValidDVIFileName(incfile)) {
 		frontend::Alert::warning(_("Problematic filename for DVI"),
 			_("The following filename can cause troubles "
-			  "when running the exported file through LaTeX "
-			  "and opening the resulting DVI: ") +
+				"when running the exported file through LaTeX "
+				"and opening the resulting DVI: ") +
 			from_utf8(incfile), true);
 	}
+
+	FileName const writefile(makeAbsPath(mangled, masterBuffer->temppath()));
+
 	LYXERR(Debug::LATEX, "incfile:" << incfile);
 	LYXERR(Debug::LATEX, "exportfile:" << exportfile);
 	LYXERR(Debug::LATEX, "writefile:" << writefile);
 
 	string const tex_format = flavor2format(runparams.flavor);
-	if (runparams.inComment || runparams.dryrun) {
-		//Don't try to load or copy the file if we're
-		//in a comment or doing a dryrun
-	} else if (isInputOrInclude(params()) &&
+
+	switch (type(params())) {
+	case VERB:
+	case VERBAST: {
+		incfile = latex_path(incfile);
+		// FIXME UNICODE
+		os << '\\' << from_ascii(params().getCmdName()) << '{'
+		   << from_utf8(incfile) << '}';
+		break;
+	}
+	case INPUT: {
+		runparams.exportdata->addExternalFile(tex_format, writefile,
+						      exportfile);
+
+		// \input wants file with extension (default is .tex)
+		if (!isLyXFileName(included_file.absFileName())) {
+			incfile = latex_path(incfile);
+			// FIXME UNICODE
+			os << '\\' << from_ascii(params().getCmdName())
+			   << '{' << from_utf8(incfile) << '}';
+		} else {
+		incfile = changeExtension(incfile, ".tex");
+		incfile = latex_path(incfile);
+			// FIXME UNICODE
+			os << '\\' << from_ascii(params().getCmdName())
+			   << '{' << from_utf8(incfile) <<  '}';
+		}
+		break;
+	}
+	case LISTINGS: {
+		os << '\\' << from_ascii(params().getCmdName());
+		string const opt = to_utf8(params()["lstparams"]);
+		// opt is set in QInclude dialog and should have passed validation.
+		InsetListingsParams params(opt);
+		if (!params.params().empty())
+			os << "[" << from_utf8(params.params()) << "]";
+		os << '{'  << from_utf8(incfile) << '}';
+		break;
+	}
+	case INCLUDE: {
+		runparams.exportdata->addExternalFile(tex_format, writefile,
+						      exportfile);
+
+		// \include don't want extension and demands that the
+		// file really have .tex
+		incfile = changeExtension(incfile, string());
+		incfile = latex_path(incfile);
+		// FIXME UNICODE
+		os << '\\' << from_ascii(params().getCmdName()) << '{'
+		   << from_utf8(incfile) << '}';
+		break;
+	}
+	case NONE:
+		break;
+	}
+
+	if (runparams.inComment || runparams.dryrun)
+		// Don't try to load or copy the file if we're
+		// in a comment or doing a dryrun
+		return;
+
+	if (isInputOrInclude(params()) &&
 		 isLyXFileName(included_file.absFileName())) {
 		// if it's a LyX file and we're inputting or including,
 		// try to load it so we can write the associated latex
@@ -618,6 +676,7 @@ void InsetInclude::latex(otexstream & os, OutputParams const & runparams) const
 		runparams.master_language = buffer().params().language;
 		runparams.par_begin = 0;
 		runparams.par_end = tmp->paragraphs().size();
+		runparams.is_child = true;
 		if (!tmp->makeLaTeXFile(tmpwritefile, masterFileName(buffer()).
 				onlyPath().absFileName(), runparams, Buffer::OnlyBody)) {
 			docstring msg = bformat(_("Included file `%1$s' "
@@ -633,6 +692,7 @@ void InsetInclude::latex(otexstream & os, OutputParams const & runparams) const
 		}
 		runparams.encoding = oldEnc;
 		runparams.master_language = oldLang;
+		runparams.is_child = false;
 
 		// If needed, use converters to produce a latex file from the child
 		if (tmpwritefile != writefile) {
@@ -674,61 +734,6 @@ void InsetInclude::latex(otexstream & os, OutputParams const & runparams) const
 			}
 		}
 	}
-
-	switch (type(params())) {
-	case VERB:
-	case VERBAST: {
-		incfile = latex_path(incfile);
-		// FIXME UNICODE
-		os << '\\' << from_ascii(params().getCmdName()) << '{'
-		   << from_utf8(incfile) << '}';
-		break;
-	} 
-	case INPUT: {
-		runparams.exportdata->addExternalFile(tex_format, writefile,
-						      exportfile);
-
-		// \input wants file with extension (default is .tex)
-		if (!isLyXFileName(included_file.absFileName())) {
-			incfile = latex_path(incfile);
-			// FIXME UNICODE
-			os << '\\' << from_ascii(params().getCmdName())
-			   << '{' << from_utf8(incfile) << '}';
-		} else {
-		incfile = changeExtension(incfile, ".tex");
-		incfile = latex_path(incfile);
-			// FIXME UNICODE
-			os << '\\' << from_ascii(params().getCmdName())
-			   << '{' << from_utf8(incfile) <<  '}';
-		}
-		break;
-	} 
-	case LISTINGS: {
-		os << '\\' << from_ascii(params().getCmdName());
-		string const opt = to_utf8(params()["lstparams"]);
-		// opt is set in QInclude dialog and should have passed validation.
-		InsetListingsParams params(opt);
-		if (!params.params().empty())
-			os << "[" << from_utf8(params.params()) << "]";
-		os << '{'  << from_utf8(incfile) << '}';
-		break;
-	} 
-	case INCLUDE: {
-		runparams.exportdata->addExternalFile(tex_format, writefile,
-						      exportfile);
-
-		// \include don't want extension and demands that the
-		// file really have .tex
-		incfile = changeExtension(incfile, string());
-		incfile = latex_path(incfile);
-		// FIXME UNICODE
-		os << '\\' << from_ascii(params().getCmdName()) << '{'
-		   << from_utf8(incfile) << '}';
-		break;
-	}
-	case NONE:
-		break;
-	}
 }
 
 
@@ -917,7 +922,9 @@ void InsetInclude::validate(LaTeXFeatures & features) const
 			// otherwise it would always be the master buffer,
 			// and nested includes would not work.
 			features.setBuffer(*tmp);
+			features.runparams().is_child = true;
 			tmp->validate(features);
+			features.runparams().is_child = false;
 			features.setBuffer(buffer());
 		}
 	}
