@@ -496,6 +496,7 @@ void InsetPrintIndex::doDispatch(Cursor & cur, FuncRequest & cmd)
 			cur.noScreenUpdate();
 			break;
 		}
+		cur.recordUndo();
 		setParams(p);
 		break;
 	}
@@ -662,9 +663,12 @@ struct IndexEntry
 
 bool operator<(IndexEntry const & lhs, IndexEntry const & rhs)
 {
-	return lhs.main < rhs.main
-			|| (lhs.main == rhs.main && lhs.sub < rhs.sub)
-			|| (lhs.main == rhs.main && lhs.sub == rhs.sub && lhs.subsub < rhs.subsub);
+	int comp = compare_no_case(lhs.main, rhs.main);
+	if (comp == 0)
+		comp = compare_no_case(lhs.sub, rhs.sub);
+	if (comp == 0)
+		comp = compare_no_case(lhs.subsub, rhs.subsub);
+	return (comp < 0);
 }
 
 } // anon namespace
