@@ -277,12 +277,16 @@ docstring InsetListings::xhtml(XHTMLStream & os, OutputParams const & rp) const
 		docstring caption = getCaptionHTML(rp);
 		if (!caption.empty())
 			out << html::StartTag("div", "class='float-caption'") 
+			    << XHTMLStream::ESCAPE_NONE
 			    << caption << html::EndTag("div");
 	}
 
 	out << html::StartTag("pre");
 	OutputParams newrp = rp;
 	newrp.html_disable_captions = true;
+	// We don't want to convert dashes here. That's the only conversion we
+	// do for XHTML, so this is safe.
+	newrp.pass_thru = true;
 	docstring def = InsetText::insetAsXHTML(out, newrp, InsetText::JustText);
 	out << html::EndTag("pre");
 
