@@ -16,6 +16,7 @@
 #include "Cursor.h"
 #include "DispatchResult.h"
 #include "InsetLabel.h"
+#include "Language.h"
 #include "LaTeXFeatures.h"
 #include "LyX.h"
 #include "OutputParams.h"
@@ -142,6 +143,9 @@ void InsetRef::latex(otexstream & os, OutputParams const & rp) const
 	string const cmd = getCmdName();
 	docstring const data = getEscapedLabel(rp);
 
+	if (rp.inulemcmd)
+		os << "\\mbox{";
+
 	if (cmd == "eqref" && buffer().params().use_refstyle) {
 		os << '(' << from_ascii("\\ref{") << data << from_ascii("})");
 	} 
@@ -159,6 +163,9 @@ void InsetRef::latex(otexstream & os, OutputParams const & rp) const
 		p["reference"] = ref;
 		os << p.getCommand(rp);
 	}
+
+	if (rp.inulemcmd)
+		os << "}";
 }
 
 
@@ -195,7 +202,7 @@ int InsetRef::docbook(odocstream & os, OutputParams const & runparams) const
 }
 
 
-docstring InsetRef::xhtml(XHTMLStream & xs, OutputParams const &) const
+docstring InsetRef::xhtml(XHTMLStream & xs, OutputParams const & op) const
 {
 	docstring const & ref = getParam("reference");
 	InsetLabel const * il = buffer().insetLabel(ref);
@@ -211,10 +218,11 @@ docstring InsetRef::xhtml(XHTMLStream & xs, OutputParams const &) const
 			// normally, would be "ref on page #", but we have no pages
 			display_string = value;
 		else if (cmd == "pageref" || cmd == "vpageref")
-			// normally would be "on page #", but we have no pages
-			display_string = _("elsewhere");
+			// normally would be "on page #", but we have no pages.
+			display_string = translateIfPossible(from_ascii("elsewhere"),
+			        op.local_font->language()->lang());
 		else if (cmd == "eqref")
-			display_string = bformat(from_ascii("equation (%1$s)"), value);
+			display_string = '(' + value + ')';
 		else if (cmd == "formatted"
 		         // we don't really have the ability to handle these 
 		         // properly in XHTML output
@@ -309,12 +317,13 @@ void InsetRef::validate(LaTeXFeatures & features) const
 		string const fcmd = to_utf8(getFormattedCmd(data, label, prefix));
 		if (buffer().params().use_refstyle) {
 			features.require("refstyle");
-			if (!prefix.empty()) {
+			if (prefix == "cha")
+				features.addPreambleSnippet("\\let\\charef=\\chapref");
+			else if (!prefix.empty()) {
 				string lcmd = "\\AtBeginDocument{\\providecommand" + 
 						fcmd + "[1]{\\ref{" + to_utf8(prefix) + ":#1}}}";
 				features.addPreambleSnippet(lcmd);
-			} else if (prefix == "cha")
-				features.addPreambleSnippet("\\let\\charef=\\chapref");
+			}
 		} else {
 			features.require("prettyref");
 			// prettyref uses "cha" for chapters, so we provide a kind of
