@@ -413,9 +413,10 @@ void InsetText::latex(otexstream & os, OutputParams const & runparams) const
 			if (runparams.lastid != -1)
 				os.texrow().start(runparams.lastid,
 						  runparams.lastpos);
-			os << "\\begin{" << from_utf8(il.latexname()) << "}\n";
+			os << "\\begin{" << from_utf8(il.latexname()) << "}";
 			if (!il.latexparam().empty())
 				os << from_utf8(il.latexparam());
+			os << "\n";
 		}
 	}
 	OutputParams rp = runparams;
@@ -526,6 +527,7 @@ docstring InsetText::insetAsXHTML(XHTMLStream & xs, OutputParams const & rp,
 	InsetLayout const & il = getLayout();
 	if (opts & WriteOuterTag)
 		xs << html::StartTag(il.htmltag(), il.htmlattr());
+
 	if ((opts & WriteLabel) && !il.counter().empty()) {
 		BufferParams const & bp = buffer().masterBuffer()->params();
 		Counters & cntrs = bp.documentClass().counters();
@@ -545,14 +547,21 @@ docstring InsetText::insetAsXHTML(XHTMLStream & xs, OutputParams const & rp,
 
 	if (opts & WriteInnerTag)
 		xs << html::StartTag(il.htmlinnertag(), il.htmlinnerattr());
-	OutputParams ours = runparams;
+
+	// we will eventually lose information about the containing inset
 	if (!il.isMultiPar() || opts == JustText)
-		ours.html_make_pars = false;
-	xhtmlParagraphs(text_, buffer(), xs, ours);
+		runparams.html_make_pars = false;
+	if (il.isPassThru())
+		runparams.pass_thru = true;
+
+	xhtmlParagraphs(text_, buffer(), xs, runparams);
+
 	if (opts & WriteInnerTag)
 		xs << html::EndTag(il.htmlinnertag());
+
 	if (opts & WriteOuterTag)
 		xs << html::EndTag(il.htmltag());
+
 	return docstring();
 }
 
