@@ -154,7 +154,9 @@ bool findOne(BufferView * bv, docstring const & searchstr,
 	if (!searchAllowed(searchstr))
 		return false;
 
-	DocIterator cur = bv->cursor();
+	DocIterator cur = forward 
+		? bv->cursor().selectionEnd() 
+		: bv->cursor().selectionBegin();
 
 	MatchString const match(searchstr, case_sens, whole);
 
@@ -275,9 +277,6 @@ pair<bool, int> replaceOne(BufferView * bv, docstring searchstr,
 	if (forward) {
 		cur.pos() += replacestr.length();
 		LASSERT(cur.pos() <= cur.lastpos(), /* */);
-	} else {
-		cur.pos() -= replacestr.length();
-		LASSERT(cur.pos() >= 0, /* */);
 	}
 	if (findnext)
 		findOne(bv, searchstr, case_sens, whole, forward, false);
@@ -448,13 +447,14 @@ bool findChange(BufferView * bv, bool next)
 	bv->cursor().setCursor(cur);
 	bv->cursor().resetAnchor();
 
+	CursorSlice & tip = cur.top();
+
 	if (!next)
 		// take a step into the change
-		cur.backwardPos();
+		tip.backwardPos();
 
-	Change orig_change = cur.paragraph().lookupChange(cur.pos());
+	Change orig_change = tip.paragraph().lookupChange(tip.pos());
 
-	CursorSlice & tip = cur.top();
 	if (next) {
 		for (; !tip.at_end(); tip.forwardPos()) {
 			Change change = tip.paragraph().lookupChange(tip.pos());
@@ -495,19 +495,20 @@ Escapes const & get_regexp_escapes()
 {
 	static Escapes escape_map;
 	if (escape_map.empty()) {
-		escape_map.push_back(pair<string, string>("$", "\\$"));
-		escape_map.push_back(pair<string, string>("{", "\\{"));
-		escape_map.push_back(pair<string, string>("}", "\\}"));
-		escape_map.push_back(pair<string, string>("[", "\\["));
-		escape_map.push_back(pair<string, string>("]", "\\]"));
-		escape_map.push_back(pair<string, string>("(", "\\("));
-		escape_map.push_back(pair<string, string>(")", "\\)"));
-		escape_map.push_back(pair<string, string>("+", "\\+"));
-		escape_map.push_back(pair<string, string>("*", "\\*"));
-		escape_map.push_back(pair<string, string>(".", "\\."));
+		escape_map.push_back(pair<string, string>("$", "_x_$"));
+		escape_map.push_back(pair<string, string>("{", "_x_{"));
+		escape_map.push_back(pair<string, string>("}", "_x_}"));
+		escape_map.push_back(pair<string, string>("[", "_x_["));
+		escape_map.push_back(pair<string, string>("]", "_x_]"));
+		escape_map.push_back(pair<string, string>("(", "_x_("));
+		escape_map.push_back(pair<string, string>(")", "_x_)"));
+		escape_map.push_back(pair<string, string>("+", "_x_+"));
+		escape_map.push_back(pair<string, string>("*", "_x_*"));
+		escape_map.push_back(pair<string, string>(".", "_x_."));
 		escape_map.push_back(pair<string, string>("\\", "(?:\\\\|\\\\backslash)"));
 		escape_map.push_back(pair<string, string>("~", "(?:\\\\textasciitilde|\\\\sim)"));
 		escape_map.push_back(pair<string, string>("^", "(?:\\^|\\\\textasciicircum\\{\\}|\\\\mathcircumflex)"));
+		escape_map.push_back(pair<string, string>("_x_", "\\"));
 	}
 	return escape_map;
 }
@@ -1421,6 +1422,9 @@ bool findAdv(BufferView * bv, FindAndReplaceOptions const & opt)
 
 	try {
 		MatchStringAdv matchAdv(bv->buffer(), opt);
+		int length = bv->cursor().selectionEnd().pos() - bv->cursor().selectionBegin().pos();
+		if (length > 0)
+			bv->putSelectionAt(bv->cursor().selectionBegin(), length, !opt.forward);
 		findAdvReplace(bv, opt, matchAdv);
 		cur = bv->cursor();
 		if (opt.forward)
