@@ -12,6 +12,8 @@
 #ifndef LYX_SUPPORT_PROGRESSINTERFACE_H
 #define LYX_SUPPORT_PROGRESSINTERFACE_H
 
+#include "support/strfwd.h"
+
 class QString;
 
 namespace lyx {
@@ -36,6 +38,9 @@ public:
 	virtual void toggleWarning(QString const & title, QString const & msg, QString const & formatted) = 0;
 	virtual void error(QString const & title, QString const & message) = 0;
 	virtual void information(QString const & title, QString const & message) = 0;
+	virtual int prompt(docstring const & title, docstring const & question,
+			   int default_button, int cancel_button,
+			   docstring const & b1, docstring const & b2) = 0;
 
 	virtual void lyxerrConnect() = 0;
 	virtual void lyxerrDisconnect() = 0;
