@@ -30,6 +30,7 @@
 #include "support/gettext.h"
 #include "support/lstrings.h"
 #include "support/os.h"
+#include "support/Messages.h"
 #include "support/Package.h"
 #include "support/Path.h"
 #include "support/Systemcall.h"
@@ -271,7 +272,7 @@ FileName const i18nLibFileSearch(string const & dir, string const & name,
 	   each po file is able to tell us its name. (JMarc)
 	*/
 
-	string lang = to_ascii(_(languageTestString()));
+	string lang = getGuiMessages().language();
 	string const language = getEnv("LANGUAGE");
 	if (!lang.empty() && !language.empty())
 		lang = language;
@@ -791,25 +792,26 @@ docstring const makeDisplayPath(string const & path, unsigned int threshold)
 		return from_utf8(os::external_path(str));
 
 	string const prefix = ".../";
-	string temp;
+	docstring dstr = from_utf8(str);
+	docstring temp;
 
-	while (str.length() > threshold)
-		str = split(str, temp, '/');
+	while (dstr.length() > threshold)
+		dstr = split(dstr, temp, '/');
 
 	// Did we shorten everything away?
-	if (str.empty()) {
+	if (dstr.empty()) {
 		// Yes, filename itself is too long.
 		// Pick the start and the end of the filename.
-		str = onlyFileName(path);
-		string const head = str.substr(0, threshold / 2 - 3);
+		dstr = from_utf8(onlyFileName(path));
+		docstring const head = dstr.substr(0, threshold / 2 - 3);
 
-		string::size_type len = str.length();
-		string const tail =
-			str.substr(len - threshold / 2 - 2, len - 1);
-		str = head + "..." + tail;
+		docstring::size_type len = dstr.length();
+		docstring const tail =
+			dstr.substr(len - threshold / 2 - 2, len - 1);
+		dstr = head + from_ascii("...") + tail;
 	}
 
-	return from_utf8(os::external_path(prefix + str));
+	return from_utf8(os::external_path(prefix + to_utf8(dstr)));
 }
 
 
