@@ -398,12 +398,6 @@ shell_type shell()
 }
 
 
-int timeout_min()
-{
-	return 3;
-}
-
-
 char path_separator(path_type type)
 {
 	if (type == TEXENGINE)
