@@ -458,12 +458,6 @@ shell_type shell()
 }
 
 
-int timeout_min()
-{
-	return 30;
-}
-
-
 char path_separator(path_type type)
 {
 	if (type == TEXENGINE)
