@@ -44,16 +44,12 @@ Preamble preamble;
 
 namespace {
 
-//add this to known_languages when updating to lyxformat 266:
-// "armenian" (needs special handling since not supported by standard babel)
-//add these to known_languages when updating to lyxformat 268:
-//"chinese-simplified", "chinese-traditional", "japanese", "korean"
-// Both changes require first that support for non-babel languages (CJK,
-// armtex) is added.
+// "chinese-simplified", "chinese-traditional", "japanese-cjk", "korean"
+// cannot be supported because it is impossible to determine the correct document
+// language if CJK is used.
 /**
  * known babel language names (including synonyms)
  * not in standard babel: arabic, arabtex, armenian, belarusian, serbian-latin, thai
- * not yet supported by LyX: kurmanji
  * please keep this in sync with known_coded_languages line by line!
  */
 const char * const known_languages[] = {"acadian", "afrikaans", "albanian",
@@ -166,8 +162,9 @@ const char * const known_if_3arg_commands[] = {"@ifundefined", "IfFileExists",
 0};
 
 /// packages that work only in xetex
+/// polyglossia is handled separately
 const char * const known_xetex_packages[] = {"arabxetex", "fixlatvian",
-"fontbook", "fontwrap", "mathspec", "philokalia", "polyglossia", "unisugar",
+"fontbook", "fontwrap", "mathspec", "philokalia", "unisugar",
 "xeCJK", "xecolor", "xecyr", "xeindex", "xepersian", "xunicode", 0};
 
 // codes used to remove packages that are loaded automatically by LyX.
@@ -276,6 +273,40 @@ string process_keyval_opt(vector<string> & options, string name)
 } // anonymous namespace
 
 
+/**
+ * known polyglossia language names (including variants)
+ */
+const char * const Preamble::polyglossia_languages[] = {
+"albanian", "croatian", "hebrew", "norsk", "swedish", "amharic", "czech", "hindi",
+"nynorsk", "syriac", "arabic", "danish", "icelandic", "occitan", "tamil",
+"armenian", "divehi", "interlingua", "polish", "telugu", "asturian", "dutch",
+"irish", "portuges", "thai", "bahasai", "english", "italian", "romanian", "turkish",
+"bahasam", "esperanto", "lao", "russian", "turkmen", "basque", "estonian", "latin",
+"samin", "ukrainian", "bengali", "farsi", "latvian", "sanskrit", "urdu", "brazil",
+"brazilian", "finnish", "lithuanian", "scottish", "usorbian", "breton", "french",
+"lsorbian", "serbian", "vietnamese", "bulgarian", "galician", "magyar", "slovak",
+"welsh", "catalan", "german", "malayalam", "slovenian", "coptic", "greek",
+"marathi", "spanish",
+"american", "british", "monotonic", "polytonic", 0};
+
+/**
+ * the same as polyglossia_languages with .lyx names
+ * please keep this in sync with polyglossia_languages line by line!
+ */
+const char * const Preamble::coded_polyglossia_languages[] = {
+"albanian", "croatian", "hebrew", "norsk", "swedish", "amharic", "czech", "hindi",
+"nynorsk", "syriac", "arabic_arabi", "danish", "icelandic", "occitan", "tamil",
+"armenian", "divehi", "interlingua", "polish", "telugu", "asturian", "dutch",
+"irish", "portuges", "thai", "bahasa", "english", "italian", "romanian", "turkish",
+"bahasam", "esperanto", "lao", "russian", "turkmen", "basque", "estonian", "latin",
+"samin", "ukrainian", "bengali", "farsi", "latvian", "sanskrit", "urdu", "brazilian",
+"brazilian", "finnish", "lithuanian", "scottish", "uppersorbian", "breton", "french",
+"lowersorbian", "serbian", "vietnamese", "bulgarian", "galician", "magyar", "slovak",
+"welsh", "catalan", "ngerman", "malayalam", "slovene", "coptic", "greek",
+"marathi", "spanish",
+"american", "british", "greek", "polutonikogreek", 0};
+
+
 bool Preamble::indentParagraphs() const
 {
 	return h_paragraph_separation == "indent";
@@ -407,6 +438,7 @@ Preamble::Preamble() : one_language(true), title_layout_found(false)
 	h_font_sf_scale           = "100";
 	h_font_tt_scale           = "100";
 	h_graphics                = "default";
+	h_default_output_format   = "default";
 	h_html_be_strict          = "false";
 	h_html_css_as_file        = "0";
 	h_html_math_output        = "0";
@@ -418,6 +450,8 @@ Preamble::Preamble() : one_language(true), title_layout_found(false)
 	//h_notefontcolor;
 	//h_options;
 	h_output_changes          = "false";
+	h_output_sync             = "0";
+	//h_output_sync_macro
 	h_papercolumns            = "1";
 	h_paperfontsize           = "default";
 	h_paperorientation        = "portrait";
@@ -585,6 +619,7 @@ void Preamble::handle_package(Parser &p, string const & name,
 	if (is_known(name, known_xetex_packages)) {
 		xetex = true;
 		h_use_non_tex_fonts = "true";
+		registerAutomaticallyLoadedPackage("fontspec");
 		if (h_inputencoding == "auto")
 			p.setEncoding("utf8");
 	}
@@ -675,11 +710,23 @@ void Preamble::handle_package(Parser &p, string const & name,
 			// reasons for it.
 			h_preamble << "\\usepackage[" << opts << "]{babel}\n";
 			delete_opt(options, known_languages);
+			// finally translate the babel name to a LyX name
+			h_language = babel2lyx(h_language);
 		}
 		else
 			h_preamble << "\\usepackage{babel}\n";
 	}
 
+	else if (name == "polyglossia") {
+		h_language_package = "default";
+		h_default_output_format = "pdf4";
+		h_use_non_tex_fonts = "true";
+		xetex = true;
+		registerAutomaticallyLoadedPackage("xunicode");
+		if (h_inputencoding == "auto")
+			p.setEncoding("utf8");
+	}
+
 	else if (name == "fontenc") {
 		h_fontencoding = getStringFromVector(options, ",");
 		/* We could do the following for better round trip support,
@@ -704,6 +751,15 @@ void Preamble::handle_package(Parser &p, string const & name,
 		options.clear();
 	}
 
+	else if (name == "srcltx") {
+		h_output_sync = "1";
+		if (!opts.empty()) {
+			h_output_sync_macro = "\\usepackage[" + opts + "]{srcltx}";
+			options.clear();
+		} else
+			h_output_sync_macro = "\\usepackage{srcltx}";
+	}
+
 	else if (is_known(name, known_old_language_packages)) {
 		// known language packages from the times before babel
 		// if they are found and not also babel, they will be used as
@@ -734,10 +790,10 @@ void Preamble::handle_package(Parser &p, string const & name,
 
 	else if (name == "array" || name == "booktabs" || name == "calc" ||
 		     name == "color" || name == "hhline" || name == "ifthen" ||
-		     name == "float" || name == "longtable" || name == "makeidx" ||
-		     name == "multirow" || name == "nomencl" || name == "setspace" ||
-		     name == "splitidx" || name == "subscript" || name == "ulem" ||
-		     name == "url") {
+		     name == "float" || name == "fontspec" || name == "longtable" ||
+			 name == "makeidx" || name == "multirow" || name == "nomencl" ||
+			 name == "setspace" || name == "splitidx" || name == "subscript" ||
+			 name == "ulem" || name == "url" || name == "xunicode") {
 		if (name == "splitidx")
 			h_use_indices = "true";
 		if (!in_lyx_preamble)
@@ -824,9 +880,6 @@ void Preamble::handle_if(Parser & p, bool in_lyx_preamble)
 
 bool Preamble::writeLyXHeader(ostream & os, bool subdoc)
 {
-	// translate from babel to LyX names
-	h_language = babel2lyx(h_language);
-
 	// set the quote language
 	// LyX only knows the following quotes languages:
 	// english, swedish, german, polish, french and danish
@@ -913,7 +966,11 @@ bool Preamble::writeLyXHeader(ostream & os, bool subdoc)
 	   << "\\font_osf " << h_font_osf << "\n"
 	   << "\\font_sf_scale " << h_font_sf_scale << "\n"
 	   << "\\font_tt_scale " << h_font_tt_scale << "\n"
-	   << "\\graphics " << h_graphics << "\n";
+	   << "\\graphics " << h_graphics << "\n"
+	   << "\\default_output_format " << h_default_output_format << "\n"
+	   << "\\output_sync " << h_output_sync << "\n";
+	if (h_output_sync == "1")
+		os << "\\output_sync_macro \"" << h_output_sync_macro << "\"\n";
 	if (!h_float_placement.empty())
 		os << "\\float_placement " << h_float_placement << "\n";
 	os << "\\paperfontsize " << h_paperfontsize << "\n"
@@ -1064,6 +1121,70 @@ void Preamble::parse(Parser & p, string const & forceclass,
 		else if (t.cs() == "pagestyle")
 			h_paperpagestyle = p.verbatim_item();
 
+		else if (t.cs() == "setdefaultlanguage") {
+			xetex = true;
+			// We don't yet care about non-language variant options
+			// because LyX doesn't support this yet, see bug #8214
+			if (p.hasOpt()) {
+				string langopts = p.getOpt();
+				// check if the option contains a variant, if yes, extract it
+				string::size_type pos_var = langopts.find("variant");
+				string::size_type i = langopts.find(',', pos_var);
+				string::size_type k = langopts.find('=', pos_var);
+				if (pos_var != string::npos){
+					string variant;
+					if (i == string::npos)
+						variant = langopts.substr(k + 1, langopts.length() - k - 2);
+					else
+						variant = langopts.substr(k + 1, i - k - 1);
+					h_language = variant;
+				}
+				p.verbatim_item();
+			} else
+				h_language = p.verbatim_item();
+			//finally translate the poyglossia name to a LyX name
+			h_language = polyglossia2lyx(h_language);
+		}
+
+		else if (t.cs() == "setotherlanguage") {
+			// We don't yet care about the option because LyX doesn't
+			// support this yet, see bug #8214
+			p.hasOpt() ? p.getOpt() : string();
+			p.verbatim_item();
+		}
+
+		else if (t.cs() == "setmainfont") {
+			// we don't care about the option
+			p.hasOpt() ? p.getOpt() : string();
+			h_font_roman = p.getArg('{', '}');
+		}
+
+		else if (t.cs() == "setsansfont" || t.cs() == "setmonofont") {
+			// LyX currently only supports the scale option
+			string scale;
+			if (p.hasOpt()) {
+				string fontopts = p.getArg('[', ']');
+				// check if the option contains a scaling, if yes, extract it
+				string::size_type pos = fontopts.find("Scale");
+				if (pos != string::npos) {
+					string::size_type i = fontopts.find(',', pos);
+					if (i == string::npos)
+						scale = scale_as_percentage(fontopts.substr(pos + 1));
+					else
+						scale = scale_as_percentage(fontopts.substr(pos, i - pos));
+				}
+			}
+			if (t.cs() == "setsansfont") {
+				if (!scale.empty())
+					h_font_sf_scale = scale;
+				h_font_sans = p.getArg('{', '}');
+			} else {
+				if (!scale.empty())
+					h_font_tt_scale = scale;
+				h_font_typewriter = p.getArg('{', '}');
+			}
+		}
+
 		else if (t.cs() == "date") {
 			string argument = p.getArg('{', '}');
 			if (argument.empty())
@@ -1338,6 +1459,19 @@ void Preamble::parse(Parser & p, string const & forceclass,
 		else if (t.cs() == "setstretch")
 			h_spacing = "other " + p.verbatim_item();
 
+		else if (t.cs() == "synctex") {
+			// the scheme is \synctex=value
+			// where value can only be "1" or "-1"
+			h_output_sync = "1";
+			// there can be any character behind the value (e.g. a linebreak or a '\'
+			// therefore we extract it char by char
+			p.get_token();
+			string value = p.get_token().asInput();
+			if (value == "-")
+				value += p.get_token().asInput();
+			h_output_sync_macro = "\\synctex=" + value;
+		}
+
 		else if (t.cs() == "begin") {
 			string const name = p.getArg('{', '}');
 			if (name == "document")
@@ -1479,6 +1613,15 @@ string babel2lyx(string const & language)
 }
 
 
+string Preamble::polyglossia2lyx(string const & language)
+{
+	char const * const * where = is_known(language, polyglossia_languages);
+	if (where)
+		return coded_polyglossia_languages[where - polyglossia_languages];
+	return language;
+}
+
+
 string rgbcolor2code(string const & name)
 {
 	char const * const * where = is_known(name, known_basic_colors);
